the module generator
==============================

The classes of the generator
------------------------------

.. toctree::
   :maxdepth: 2

   the generic class Generator <../class/class_Generator>
   the Numpy generator <../class/class_NumpyGenerator>
   the Cython generator <../class/class_CythonGenerator>

The classes of the ode solvers
-------------------------------

.. toctree::
   :maxdepth: 2

   the generic class for the ODE solvers <../class/class_ODE_solver>
   the basic ode solver <../class/class_ode_basic>
   the explicit Euler method <../class/class_explicit_euler>
   the Heun method <../class/class_heun>
   the middle point method <../class/class_middle_point>
   the 4th order Runge Kutta method <../class/class_RK4>
